Struct EdkiiIommuProtocol
Source #[repr(C)]
pub struct EdkiiIommuProtocol {
pub revision: u64,
pub set_attribute: unsafe extern "efiapi" fn(this: *const Self, device_handle: Handle, mapping: *mut c_void, iommu_access: EdkiiIommuAccess) -> Status,
pub map: unsafe extern "efiapi" fn(this: *const Self, operation: EdkiiIommuOperation, host_address: *mut c_void, number_of_bytes: *mut usize, device_address: *mut u64, mapping: *mut *mut c_void) -> Status,
pub unmap: unsafe extern "efiapi" fn(this: *const Self, mapping: *mut c_void) -> Status,
pub allocate_buffer: unsafe extern "efiapi" fn(this: *const Self, allocate_type: AllocateType, memory_type: MemoryType, pages: usize, host_address: *mut *mut c_void, attributes: EdkiiIommuAttribute) -> Status,
pub free_buffer: unsafe extern "efiapi" fn(this: *const Self, pages: usize, host_address: *mut c_void) -> Status,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.